@@ -4,8 +4,8 @@
 ;;               2022–2025 anki-editor contributors
 
 ;; Author: Lei Tan
-;; Package-Version: 20251014.713
-;; Package-Revision: b756af5afc9a
+;; Package-Version: 20251107.1231
+;; Package-Revision: 9289601129d4
 ;; URL: https://github.com/anki-editor/anki-editor
 ;; Package-Requires: ((emacs "29.1"))
 
@@ -1153,7 +1153,8 @@ Return a list of cons of (FIELD-NAME . FIELD-CONTENT)."
 (defun anki-editor--property-fields (fields)
   "Extract Anki FIELDS from entry properties."
   (cl-loop for field in fields
-           for property = (concat anki-editor-prop-field-prefix (upcase field))
+           for property = (concat anki-editor-prop-field-prefix
+                                  (string-replace " " "_" (upcase field)))
            for property-value = (org-entry-get-with-inheritance property)
            when property-value
            collect (cons field property-value)))
